diff frontends/src/jp/base.py @ 1367:f71a0fc26886

merged branch frontends_multi_profiles
author Goffi <goffi@goffi.org>
date Wed, 18 Mar 2015 10:52:28 +0100
parents faa1129559b8
children 1ae9aa94c351
line wrap: on
line diff
--- a/frontends/src/jp/base.py	Thu Feb 05 11:59:26 2015 +0100
+++ b/frontends/src/jp/base.py	Wed Mar 18 10:52:28 2015 +0100
@@ -245,11 +245,11 @@
         callback()
 
     def get_full_jid(self, param_jid):
         """Return the full jid if possible (add last resource when find a bare jid)"""
         _jid = JID(param_jid)
         if not _jid.resource:
             #if the resource is not given, we try to add the last known resource
-            last_resource = self.bridge.getLastResource(param_jid, self.profile)
+            last_resource = self.bridge.getMainResource(param_jid, self.profile)
             if last_resource:
                 return "%s/%s" % (_jid.bare, last_resource)
         return param_jid
@@ -245,11 +245,11 @@
 
     def get_full_jid(self, param_jid):
-        """Return the full jid if possible (add last resource when find a bare jid)"""
+        """Return the full jid if possible (add main resource when find a bare jid)"""
         _jid = JID(param_jid)
         if not _jid.resource: